# (akien) The Vulkan SDK requires some care when updating.
# Check instructions in the vulkan-headers spec file.

%define major   1
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d

Name:		vkd3d
Version:	1.11
Release:	%mkrel 1
Summary:	D3D12 to Vulkan translation library
Group:          System/Libraries

License:	LGPLv2+
URL:		https://source.winehq.org/git/vkd3d.git
Source0:	https://dl.winehq.org/vkd3d/source/%{name}-%{version}.tar.xz
Source1:	https://dl.winehq.org/vkd3d/source/%{name}-%{version}.tar.xz.sign

BuildRequires:	make
BuildRequires:	bison
BuildRequires:	flex
BuildRequires:	gcc
BuildRequires:	pkgconfig(SPIRV-Tools)
BuildRequires:	pkgconfig(vulkan)
BuildRequires:	pkgconfig(xcb)
BuildRequires:	pkgconfig(xcb-keysyms)
BuildRequires:	pkgconfig(xcb-icccm)
BuildRequires:	pkgconfig(xcb-util)
BuildRequires:	spirv-headers

BuildRequires:	mingw32-filesystem >= 95
BuildRequires:	mingw32-gcc
BuildRequires:	mingw32-spirv-headers
BuildRequires:	mingw32-spirv-tools
BuildRequires:	mingw32-vulkan-headers
BuildRequires:	mingw32-vulkan-loader

BuildRequires:	mingw64-filesystem >= 95
BuildRequires:	mingw64-gcc
BuildRequires:	mingw64-spirv-headers
BuildRequires:	mingw64-spirv-tools
BuildRequires:	mingw64-vulkan-headers
BuildRequires:	mingw64-vulkan-loader

%description
The vkd3d project includes libraries, shaders, utilities, and demos for
translating D3D12 to Vulkan.


%package -n %{libname}
Summary:	D3D12 to Vulkan translation library
Group:          System/Libraries
Obsoletes:      %{_lib}vkd3d-utils1 < 1.2-1

%description -n %{libname}
Vkd3d is a 3D graphics library built on top of Vulkan. It has an API very
similar, but not identical, to Direct3D 12.

Vkd3d can be used by projects that target Direct3D 12 as a drop-in replacement
at build-time with some modest source modifications.

%package -n %{devname}
Summary:	Development files for vkd3d
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Obsoletes:      %{_lib}vkd3d-utils-devel < 1.2-1


%description -n %{devname}
Development files for vkd3d.


%package -n mingw32-%{name}
Summary:	%{summary}
BuildArch:	noarch


%description -n mingw32-%{name}
%{summary}.


%package -n mingw64-%{name}
Summary:	%{summary}
BuildArch:	noarch


%description -n mingw64-%{name}
%{summary}.


%{?mingw_debug_package}


%prep
%autosetup
mkdir ../mingw-build
cp -rp . ../mingw-build


%build
%configure
%make_build

pushd ../mingw-build
export SONAME_LIBVULKAN=lvulkan-1
%mingw_configure
%mingw_make
popd


%install
%make_install
pushd ../mingw-build
%mingw_make_install
%mingw_debug_install_post
popd

#Remove libtool files and static libraries
find %{buildroot} -regextype egrep -regex '.*\.a$|.*\.la$' ! -iname '*.dll.a' -delete


%files -n %{libname}
%doc AUTHORS INSTALL README
%license COPYING LICENSE
%{_libdir}/lib%{name}.so.%{major}{,.*}
%{_libdir}/lib%{name}-shader.so.%{major}{,.*}
%{_libdir}/lib%{name}-utils.so.%{major}{,.*}


%files -n %{devname}
# (tv) to be split in vkd3d-compiler?
%{_bindir}/%{name}-compiler
%{_bindir}/vkd3d-dxbc
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_libdir}/lib%{name}-shader.so
%{_libdir}/lib%{name}-utils.so
%{_libdir}/pkgconfig/lib%{name}.pc
%{_libdir}/pkgconfig/lib%{name}-shader.pc
%{_libdir}/pkgconfig/lib%{name}-utils.pc



%files -n mingw32-%{name}
%license COPYING LICENSE
%{mingw32_bindir}/libvkd3d-1.dll
%{mingw32_bindir}/libvkd3d-shader-1.dll
%{mingw32_bindir}/libvkd3d-utils-1.dll
%{mingw32_includedir}/%{name}/
%{mingw32_bindir}/vkd3d-compiler.exe
%{mingw32_bindir}/vkd3d-dxbc.exe
%{mingw32_libdir}/pkgconfig/libvkd3d.pc
%{mingw32_libdir}/pkgconfig/libvkd3d-shader.pc
%{mingw32_libdir}/pkgconfig/libvkd3d-utils.pc
%{mingw32_libdir}/libvkd3d.dll.a
%{mingw32_libdir}/libvkd3d-shader.dll.a
%{mingw32_libdir}/libvkd3d-utils.dll.a


%files -n mingw64-%{name}
%license COPYING LICENSE
%{mingw64_bindir}/libvkd3d-1.dll
%{mingw64_bindir}/libvkd3d-shader-1.dll
%{mingw64_bindir}/libvkd3d-utils-1.dll
%{mingw64_bindir}/vkd3d-compiler.exe
%{mingw64_bindir}/vkd3d-dxbc.exe
%{mingw64_includedir}/%{name}/
%{mingw64_libdir}/pkgconfig/libvkd3d.pc
%{mingw64_libdir}/pkgconfig/libvkd3d-shader.pc
%{mingw64_libdir}/pkgconfig/libvkd3d-utils.pc
%{mingw64_libdir}/libvkd3d.dll.a
%{mingw64_libdir}/libvkd3d-shader.dll.a
%{mingw64_libdir}/libvkd3d-utils.dll.a



%changelog
* Fri May 17 2024 daviddavid <daviddavid> 1.11-1.mga10
+ Revision: 2064555
- new version: 1.11

* Fri Jan 19 2024 daviddavid <daviddavid> 1.10-1.mga10
+ Revision: 2032176
- new version: 1.10

* Sat Oct 14 2023 daviddavid <daviddavid> 1.9-1.mga10
+ Revision: 1996712
- new version: 1.9

* Wed Sep 06 2023 daviddavid <daviddavid> 1.8-1.mga10
+ Revision: 1984605
- new version: 1.8

* Sat Jan 21 2023 tv <tv> 1.6-1.mga9
+ Revision: 1934741
- 1.6

* Mon Nov 14 2022 akien <akien> 1.5-2.mga9
+ Revision: 1907220
- Rebuild against Vulkan/SPIRV SDK 1.3.231.1

* Sat Nov 05 2022 tv <tv> 1.5-1.mga9
+ Revision: 1903716
- 1.5
- Include MinGW debuginfo packages

* Wed Jul 20 2022 tv <tv> 1.4-1.mga9
+ Revision: 1869582
- 1.4
- Initial MinGW package for wine 7.12

* Wed Mar 30 2022 umeabot <umeabot> 1.3-2.mga9
+ Revision: 1835039
- Mageia 9 Mass Rebuild

* Tue Mar 08 2022 akien <akien> 1.3-1.mga9
+ Revision: 1789690
- Version 1.3

* Mon Oct 12 2020 akien <akien> 1.2-2.mga8
+ Revision: 1633974
- Rebuild for Vulkan SDK 1.2.154.0

* Tue Sep 22 2020 akien <akien> 1.2-1.mga8
+ Revision: 1629444
- Version 1.2
- Merge different libraries in the same packages, we don't need that much granularity for now

* Mon Feb 17 2020 akien <akien> 1.1-5.mga8
+ Revision: 1536929
- Rebuild for spirv-tools and Vulkan SDK 1.2.131.2

* Sun Feb 16 2020 umeabot <umeabot> 1.1-4.mga8
+ Revision: 1533963
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Sep 25 2019 akien <akien> 1.1-3.mga8
+ Revision: 1445843
- Rebuild for spirv-tools and Vulkan SDK 1.1.121.0

* Tue Dec 11 2018 akien <akien> 1.1-2.mga7
+ Revision: 1340228
- Rebuild to pick updated spirv-tools on armv7hl

* Tue Dec 11 2018 akien <akien> 1.1-1.mga7
+ Revision: 1340212
- imported package vkd3d

